@@ -1,6 +1,6 @@
 package org.ovirt.engine.core.bll.storage.disk;
 
-import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -9,9 +9,9 @@ import java.util.Map;
 import javax.inject.Inject;
 
 import org.ovirt.engine.core.bll.LockMessagesMatchUtil;
+import org.ovirt.engine.core.bll.NonTransactiveCommandAttribute;
 import org.ovirt.engine.core.bll.ValidationResult;
 import org.ovirt.engine.core.bll.context.CommandContext;
-import org.ovirt.engine.core.bll.storage.disk.managedblock.ManagedBlockStorageCommandUtil;
 import org.ovirt.engine.core.bll.utils.PermissionSubject;
 import org.ovirt.engine.core.bll.validator.VmValidator;
 import org.ovirt.engine.core.bll.validator.storage.DiskValidator;
@@ -45,7 +45,6 @@ import org.ovirt.engine.core.common.utils.VmDeviceType;
 import org.ovirt.engine.core.common.validation.group.UpdateEntity;
 import org.ovirt.engine.core.common.vdscommands.VDSCommandType;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.core.dao.DiskImageDao;
 import org.ovirt.engine.core.dao.DiskVmElementDao;
 import org.ovirt.engine.core.dao.ImageDao;
 import org.ovirt.engine.core.dao.SnapshotDao;
@@ -53,7 +52,9 @@ import org.ovirt.engine.core.dao.StorageDomainDao;
 import org.ovirt.engine.core.dao.StoragePoolIsoMapDao;
 import org.ovirt.engine.core.dao.VmDeviceDao;
 import org.ovirt.engine.core.dao.VmStaticDao;
+import org.ovirt.engine.core.utils.transaction.TransactionSupport;
 
+@NonTransactiveCommandAttribute(forceCompensation = true)
 public class AttachDiskToVmCommand<T extends AttachDetachVmDiskParameters> extends AbstractDiskVmCommand<T> {
 
     @Inject
@@ -72,14 +73,14 @@ public class AttachDiskToVmCommand<T extends AttachDetachVmDiskParameters> exten
     private ImageDao imageDao;
     @Inject
     private SnapshotDao snapshotDao;
-    @Inject
-    private ManagedBlockStorageCommandUtil managedBlockStorageCommandUtil;
-    @Inject
-    private DiskImageDao diskImageDao;
 
     private List<PermissionSubject> permsList = null;
     private Disk disk;
 
+    public AttachDiskToVmCommand(Guid commandId) {
+        super(commandId);
+    }
+
     public AttachDiskToVmCommand(T parameters, CommandContext commandContext) {
         super(parameters, commandContext);
     }
@@ -216,34 +217,35 @@ public class AttachDiskToVmCommand<T extends AttachDetachVmDiskParameters> exten
 
     @Override
     protected void executeVmCommand() {
-        if (!isOperationPerformedOnDiskSnapshot()) {
-            vmStaticDao.incrementDbGeneration(getVm().getId());
-        }
-
-        final VmDevice vmDevice = createVmDevice();
-        vmDeviceDao.save(vmDevice);
+        VmDevice vmDevice = createVmDevice();
 
         DiskVmElement diskVmElement = getDiskVmElement();
         diskVmElement.getId().setDeviceId(disk.getId());
-        diskVmElementDao.save(diskVmElement);
 
         // When performing hot plug for VirtIO-SCSI or SPAPR_VSCSI the address map calculation needs this info to be populated
         disk.setDiskVmElements(Collections.singletonList(diskVmElement));
 
         // update cached image
-        List<Disk> imageList = new ArrayList<>();
-        imageList.add(disk);
-        vmHandler.updateDisksForVm(getVm(), imageList);
+        vmHandler.updateDisksForVm(getVm(), Collections.singletonList(disk));
 
-        if (!isOperationPerformedOnDiskSnapshot()) {
-            if (disk.isAllowSnapshot()) {
+        TransactionSupport.executeInNewTransaction(() -> {
+            vmDeviceDao.save(vmDevice);
+            diskVmElementDao.save(diskVmElement);
+            getCompensationContext().snapshotNewEntities(Arrays.asList(vmDevice, diskVmElement));
+            if (!isOperationPerformedOnDiskSnapshot() && disk.isAllowSnapshot()) {
                 updateDiskVmSnapshotId();
             }
-        }
+            getCompensationContext().stateChanged();
+            return null;
+        });
 
         if (getParameters().isPlugUnPlug() && getVm().getStatus() != VMStatus.Down && getVm().isManaged()) {
             performPlugCommand(VDSCommandType.HotPlugDisk, disk, vmDevice);
         }
+
+        if (!isOperationPerformedOnDiskSnapshot()) {
+            vmStaticDao.incrementDbGeneration(getVm().getId());
+        }
         setSucceeded(true);
     }
 
@@ -266,15 +268,15 @@ public class AttachDiskToVmCommand<T extends AttachDetachVmDiskParameters> exten
     }
 
     private void updateDiskVmSnapshotId() {
-        Guid snapshotId = snapshotDao.getId(getVmId(), SnapshotType.ACTIVE);
-        if (disk.getDiskStorageType().isInternal()) {
-            DiskImage diskImage = (DiskImage) disk;
-            imageDao.updateImageVmSnapshotId(diskImage.getImageId(),
-                    snapshotId);
-        } else {
+        if (!disk.getDiskStorageType().isInternal()) {
             throw new EngineException(EngineError.StorageException,
                     "update of snapshot id was initiated for unsupported disk type");
         }
+
+        Guid snapshotId = snapshotDao.getId(getVmId(), SnapshotType.ACTIVE);
+        DiskImage diskImage = (DiskImage) disk;
+        getCompensationContext().snapshotEntity(diskImage);
+        imageDao.updateImageVmSnapshotId(diskImage.getImageId(), snapshotId);
     }
 
     @Override
