@@ -571,17 +571,22 @@ class Plugin(plugin.PluginBase):
             )
         )
 
-    def _sanitize_ovn_key_file_permissions(self, file_path, enable_logging):
+    def _set_file_permissions(
+            self,
+            file_path,
+            enable_logging,
+            desired_permissions
+    ):
         current_permissions = stat.S_IMODE(
             os.lstat(
                 file_path
             ).st_mode
         )
-        desired_permissions = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP
         if desired_permissions != current_permissions:
             if enable_logging:
                 self.logger.info(_(
-                    'Setting permissions on {file} to enable OVN to read it.'
+                    'Setting permissions on {file} '
+                    'to enable OVN and engine to read it.'
                 ).format(
                     file=file_path
                 ))
@@ -593,6 +598,13 @@ class Plugin(plugin.PluginBase):
                 desired_permissions
             )
 
+    def _sanitize_ovn_key_file_permissions(self, file_path, enable_logging):
+        desired_permissions = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP
+        self._set_file_permissions(
+            file_path,
+            enable_logging,
+            desired_permissions
+        )
         desired_gid = grp.getgrnam('hugetlbfs').gr_gid
         current_gid = os.stat(file_path).st_gid
         if desired_gid != current_gid:
@@ -810,6 +822,11 @@ class Plugin(plugin.PluginBase):
                 'pass': truststore_password,
             },
         )
+        self._set_file_permissions(
+            truststore,
+            True,
+            stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH,
+        )
 
     def _is_provider_installed(self):
         # TODO: we currently only check against installations done by
